/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React from 'react';
import MuiExpansionPanel from '@material-ui/core/ExpansionPanel';
import MuiExpansionPanelSummary from '@material-ui/core/ExpansionPanelSummary';
import MuiExpansionPanelDetails from '@material-ui/core/ExpansionPanelDetails';
import Typography from '@material-ui/core/Typography';
import { Link } from 'react-router-dom'
import Grid from '@material-ui/core/Grid';
import AddIcon from '@material-ui/icons/Add';
import RemoveIcon from '@material-ui/icons/Remove';
import styled from 'styled-components';



const TypographyColorido = styled(Typography)`

  color: #666 !important;
`

const MuiExpansionPanelMargem = styled(MuiExpansionPanel)`
  .expanded{
    margin: 0 0 0 0 !important;
  }
`

const MuiExpansionPanelSummaryColorido = styled(MuiExpansionPanelSummary)`
  background-color:#e5e5e5 !important;
`


const MuiExpansionPanelDetailsColorido = styled(MuiExpansionPanelDetails)`
  background-color: #fff;
`


export default function CustomizedExpansionPanels() {
  const [expanded, setExpanded] = React.useState('panel1');

  const handleChange = panel => (event, newExpanded) => {
    setExpanded(newExpanded ? panel : false);
  };

  return (
    <div style={{backgroundColor: "#e5e5e5"}}>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel1'} onChange={handleChange('panel1')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel1d-content" id="panel1d-header">
          <TypographyColorido>1. Características da <strong>Plataforma Integrada de RED do MEC</strong></TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
          <Grid container spacing={3}>
            <Grid item xs={12} md={7}>
              <div>
                <p>A <strong>Plataforma Integrada de RED do MEC</strong> é um é sítio (website) em formato de plataforma
                interativa colaborativa para propiciar a formação de uma rede de pessoas interessadas em usar, criar e compartilhar recursos e materiais educacionais. Seu objetivo é reunir e disponibilizar conteúdos do acervo do MEC, antes distribuídos em diferentes portais (Portal do Professor, Banco Internacional de Objetos Educacionais, Domínio Público e TV Escola), conteúdo de organizações parceiras, bem como fomentar espaços de participação, criação e compartilhamento de conhecimento entre usuários para temas relacionados à educação básica brasileira. A <strong>Plataforma Integrada de RED do MEC</strong> foi criada em software livre, cujas informações para desenvolvedores estão disponíveis em <a style={{color:"#00BCD4"}} href="https://gitlab.c3sl.ufpr.br/portalmec" target="_blank">gitlab.c3sl.ufpr.br/portalmec</a>.</p>
                <p>A <strong>Plataforma Integrada de RED do MEC</strong> funciona ao mesmo tempo como repositório e referatório:</p>
                <ul>
                  <li>
                    <p>Repositório: sítio na web que armazena conteúdos diversos (texto, áudio, vídeo, multimídia, etc.). Ou seja, um repositório efetivamente guarda uma cópia do recurso educacional. Todos os conteúdos depositados na <strong>Plataforma Integrada de RED do MEC</strong> têm uma licença livre e são considerados Recursos Educacionais Abertos. (Veja a seção 4, “Licença de uso do conteúdo”).</p>
                  </li>
                  <li>
                    <p>Referatório: sítio na web que indica ou aponta para conteúdos diversos em sites externos, sem armazená-los. Nesse caso, o conteúdo não está armazenado na <strong>Plataforma Integrada de RED do MEC</strong>, que somente indica a localização do recurso através de um link. Os conteúdos referenciados podem ser fechados ou abertos. (Veja a seção 4 “Licença de uso do conteúdo”).</p>
                  </li>
                </ul>
                <p>No que se refere ao Repositório, a <strong>Plataforma Integrada de RED do MEC</strong> disponibiliza recursos educacionais digitais e materiais de formação de seu acervo e também permite que usuários (pessoas físicas) depositem (publiquem, façam upload) seus recursos e materiais para serem armazenados, desde que façam seu cadastro, disponibilizem as informações necessárias no momento da publicação e respeitem as regras estabelecidas neste Termo.</p>
                <p>Os usuários terão acesso a uma variedade de recursos on-line. Para além, mediante cadastro, terão a sua disposição um maior número de funcionalidades, incluindo ferramentas de comunicação e interação, mecanismos de consulta, poderão fazer upload e download de recursos educacionais digitais. Poderão utilizar serviços relacionados à criação, à consulta e ao acompanhamento de coleções de recursos educacionais digitais de outros usuários, dentre outras funcionalidades. Professores cadastrados e identificados poderão ainda fazer upload de RED.</p>
                <p>No que se refere ao Referatório, a <strong>Plataforma Integrada de RED do MEC</strong> indica e organiza links externos para recursos e materiais de terceiros. Os recursos serão disponibilizados mediante a adesão aos critérios específicos levantados pelo MEC. Para mais informações, utilize a página de <a style={{color:"#00BCD4"}} href="contato">Contato</a> da plataforma.</p>
              </div>
            </Grid>
            <Grid item  xs={12} md={1}></Grid>
            <Grid item xs={12} md={4}>
              <div style={{color:"#00BCD4"}}>
                <p>BASICAMENTE,</p>
                <p>A Plataforma MEC RED reúne e disponibiliza conteúdos do acervo do MEC que antes estavam distribuídos em diferentes portais.</p>
                <p>Esses conteúdos podem estar armazenados na própria Plataforma, ou podem estar em sites externos, sendo indicados pela Plataforma e acessados por meio dela. </p>
                <p>Além disso, a Plataforma propicia a formação de uma rede interessada em usar, criar e compartilhar recursos e materiais educacionais.</p>
              </div>
            </Grid>
          </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel2'} onChange={handleChange('panel2')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel2d-content" id="panel2d-header">
          <TypographyColorido>2. Cadastro e segurança</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
          <Grid container spacing={3}>
            <Grid item xs={12} md={7}>
              <div>
                <p>A realização de cadastro pode ser exigida como condição para a utilização de determinados ambientes, recursos ou ferramentas. O cadastramento de um usuário só será finalizado ao serem preenchidos todos os campos indicados como obrigatórios. Para o registro de sua conta, o usuário deverá indicar uma senha e uma identificação, tornando-se responsável por mantê-las em sigilo, assumindo a total responsabilidade pelas atividades que se realizam por meio dela. O usuário compromete-se igualmente em sair ("deslogar") de sua conta ao final de cada sessão.</p>
                <p>Além das informações básicas, aos professores que quiserem ter a sua identidade verificada - o que o permitirá depositar recursos na plataforma (fazer upload) - será necessário identificar a escola da rede em que atua. A mesma informação será verificada a partir dos dados do Censo Escolar.</p>
                <p>A <strong>Plataforma Integrada de RED do MEC</strong> não se responsabiliza pelas informações inseridas por seus usuários. Os usuários garantem e respondem, em qualquer caso, pela veracidade, exatidão e autenticidade dos dados pessoais cadastrados. A <strong>Plataforma Integrada de RED do MEC</strong> se reserva o direito de conferir a identificação de seus usuários, bem como de solicitar dados adicionais e documentos que julgue pertinentes, a fim de verificar os dados pessoais informados caso julgue necessário.</p>
                <p>Para acessar sua conta, o usuário deverá identificar-se por meio de e-mail e senha. O usuário compromete-se a não informar a terceiros sua senha, responsabilizando-se integral e exclusivamente pelo uso que dela seja feito e pelas operações efetuadas em sua conta.</p>
                <p>O usuário compromete-se a notificar a <strong>Plataforma Integrada de RED do MEC</strong>, por meio da funcionalidade “Contato”, sobre qualquer uso não autorizado de sua conta, assim como sobre o seu acesso por terceiros não autorizados.</p>
                <p>Contas de usuários com informações consideradas inadequadas pela <strong>Plataforma Integrada de RED do MEC</strong>, conforme as cláusulas destes Termos de Uso, poderão ser desativadas, removidas ou ter seu conteúdo bloqueado por decisão do Ministério da Educação. O usuário será notificado através do seu e-mail de cadastro.</p>
                <p>A criação de conta ou a disponibilização de conteúdo na <strong>Plataforma Integrada de RED do MEC</strong> não geram nenhum direito de suporte técnico ou de indenização por dificuldades técnicas ou falhas nos sistemas. O cancelamento, a suspensão, a perda de dados armazenados, a indisponibilidade ou outra situação adversa que afete o acesso, os dados ou o conteúdo do usuário não ensejarão qualquer tipo de reparação, compensação ou outra obrigação.</p>
                <p>A <strong>Plataforma Integrada de RED do MEC</strong> não se responsabiliza por qualquer dano, prejuízo ou perda no equipamento do usuário causado por falhas no sistema, no servidor ou na internet decorrentes de condutas de terceiros, de vírus por acesso, da utilização ou navegação na internet ou da transferência de dados.</p>
              </div>
            </Grid>
            <Grid item xs={12} md={1}></Grid>
            <Grid item xs={12} md={4}>
              <div style={{color:"#00BCD4"}}>
                <p>BASICAMENTE,</p>
                <p>Para utilizar determinados recursos e ferramentas, o usuário precisa efetuar o cadastro no sistema, informando um e-mail válido e cadastrando uma senha.</p>
                <p>O usuário é o único responsável pelas informações que fornece. E a Plataforma MEC RED se reserva o direito de conferir a veracidade desses dados, caso julgue necessário.</p>
                <p>Se houver qualquer tipo de acesso e uso não autorizado em sua conta, o usuário compromete-se a notificar a Plataforma por meio da funcionalidade “Reportar”.</p>
                <p>A criação de conta não gera direito à suporte técnico ou indenização por dificuldades técnicas ou falhas no sistema.</p>
              </div>
            </Grid>
          </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel3'} onChange={handleChange('panel3')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel3d-content" id="panel3d-header">
          <TypographyColorido>3. Publicações de usuários</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
          <Grid container spacing={3}>
            <Grid item xs={12} md={7}>
              <div>
                <p>O conteúdo disponibilizado pelo usuário é de inteira responsabilidade do usuário, não sendo a <strong>Plataforma Integrada de RED do MEC</strong> responsável por quaisquer fatos decorrentes de sua utilização.</p>
                <p>Os recursos publicados devem ter cunho educacional, mantendo-se dentro do assunto em que estão inseridos, em conformidade com estes Termos de Uso.</p>
                <p>Todas as informações publicadas na <strong>Plataforma Integrada de RED do MEC</strong>, como os metadados (descritivos dos recursos), comentários e discussões inseridas são consideradas públicas, visíveis por qualquer pessoa, sem nenhum tipo de confidencialidade. Não serão aceitos materiais que contenham vocabulário ofensivo ou desrespeitoso a terceiros, incluindo ofensas, calúnias, injúrias e difamações. Também não serão permitidos materiais que invadam a privacidade de terceiros, que sejam ameaçadoras, preconceituosas ou racistas.</p>
                <p>Caso o usuário entenda que alguma postagem, material, notícia, comentário ou outro conteúdo disponibilizado na <strong>Plataforma Integrada de RED do MEC</strong> violem algum direito seu, a legislação aplicável ou as cláusulas deste Termos de Uso, deverá notificar a <strong>Plataforma Integrada de RED do MEC</strong> por meio da funcionalidade “Reportar” ou, quando não houver, através do formulário de Contato.</p>
                <p>O spam (mensagens não solicitadas) ou o abuso em comentários poderão ser ativamente prevenidos através do bloqueio de palavras e expressões predeterminadas, ou excluídos posteriormente, sendo cabível a remoção da conta do usuário, no caso de tentativas de violação sistemática e repetitiva destes Termos de Uso, incluindo a reintrodução de material que já tenha sido previamente bloqueado ou excluído.</p>
                <p>Conteúdos com informações consideradas inadequadas pela <strong>Plataforma Integrada de RED do MEC</strong>, conforme as cláusulas destes Termos de Uso, poderão ser removidos por decisão do Ministério da Educação e o usuário será notificado através do seu e-mail de cadastro.</p>
                <h6 style={{fontSize:"18px",marginBlock:"10px"}} >3.1 É permitido ao usuário:</h6>
                <ul>
                  <li>
                    <p>Depositar (publicar) recurso ou material de sua autoria ou de autoria coletiva, com anuência dos demais autores, que esteja em domínio público, ou para o qual há anuência dos autores originais, desde que os dados sejam corretamente preenchidos nos campos descritivos  (metadados)  indicados para preenchimento das informações sobre os recursos;</p>
                  </li>
                  <li>
                    <p>Nos comentários, contatos e comunicações, é fundamental ser cortês e tratar os demais usuários com respeito;</p>
                  </li>
                  <li>
                    <p>O usuário poderá sugerir links para outros sites, desde que tenham relação direta com o assunto abordado.</p>
                  </li>
                </ul>
                <h6 style={{fontSize:"18px",marginBlock: "10px"}}>3.2 É vedado ao usuário:</h6>
                <ul>
                  <li>
                    <p>Transmitir, exibir, enviar, ou de qualquer outra forma, disponibilizar conteúdo que contenha material pornográfico e/ou atividades ilegais relativas a menores de 18 anos (consoante o <a style={{color:"#00BCD4"}} href="http://www.planalto.gov.br/ccivil_03/leis/L8069.htm" target="_blank">Estatuto da Criança e do Adolescente</a>), que invada a privacidade de terceiros, que tenha cunho comercial, viole os <a style={{color:"#00BCD4"}} href="http://www.onu.org.br/img/2014/09/DUDH.pdf" target="_blank">Direitos Humanos</a> ou seja ilegal, ofensivo, ameaçador, que incite a violência, seja vulgar, preconceituoso ou racista (como descrito nos artigos 138-140 do Código Penal Brasileiro), ou de qualquer forma seja contrário às cláusulas destes Termos de Uso;</p>
                  </li>
                  <li>
                    <p>Assumir a identidade de outra pessoa, física ou jurídica; forjar cabeçalhos, ou de qualquer outra forma manipular identificadores, a fim de disfarçar a origem de qualquer material contido na plataforma, com sentido de desmoralizar, desprestigiar ou se fazer passar pela <strong>Plataforma Integrada de RED do MEC</strong>;</p>
                  </li>
                  <li>
                    <p>Disponibilizar conteúdo em desconformidade com a <a style={{color:"#00BCD4"}} href="http://www.planalto.gov.br/ccivil_03/leis/L9610.htm" target="_blank">legislação de Direito Autoral</a>, incluindo conteúdo que viole marca registrada, patente, segredo de negócio, direito autoral ou qualquer outro direito de terceiro; disponibilizar conteúdo com qualquer tipo de propaganda, material promocional, spam (mensagens não solicitadas), correntes ou esquemas de pirâmide;</p>
                  </li>
                  <li>
                    <p>Disponibilizar conteúdo que contenha vírus ou qualquer outro código, arquivo ou programa de computador, com o propósito de interromper, destruir ou limitar a funcionalidade de qualquer software, hardware ou equipamento de telecomunicações;</p>
                  </li>
                  <li>
                    <p>Interferir ou interromper os serviços, as redes ou os servidores conectados à plataforma de modo a dificultar a utilização e o aproveitamento dos serviços por outros usuários, bem como obter ou tentar obter acesso não autorizado à plataforma;</p>
                  </li>
                  <li>
                    <p>Pedir votos, mencionar número de candidato ou expressar qualquer outra manifestação que se caracterize como propaganda política ou que viole as normas eleitorais.</p>
                  </li>
                </ul>
              </div>
            </Grid>
            <Grid item xs={12} md={1}></Grid>
            <Grid item xs={12} md={4}>
              <div style={{color:"#00BCD4"}}>
                <p>BASICAMENTE,</p>
                <p>O conteúdo disponibilizado pelo usuário é de sua inteira responsabilidade. Os recursos publicados tevem ter cunho educacional, em conformidade com estes Termos.</p>
                <p>Todas informações publicadas na Plataforma MEC RED são cosideradas públicas, visíveis por qualquer pessoa.</p>
                <p>Não serão aceitos materiais com vocabulário ofensivo ou que invadam a privacidade de terceiros.</p>
                <p>Caso o usuário entenda que algum conteúdo disponibilizado viole um direito ou as cláusulas deste Termo de Uso, deverá notificar a Plataforma por meio da funcionalidade “Reportar”.</p>
                <p>O usuário poderá ter a sua conta removida em casos de violações sistemáticas destes Termos de Uso.</p>
              </div>
            </Grid>
          </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel4'} onChange={handleChange('panel4')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel4d-content" id="panel4d-header">
          <TypographyColorido>4. Licença de uso do conteúdo</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
          <Grid container spacing={3}>
            <Grid item xs={12} md={7}>
              <div>
                <p>A <strong>Plataforma Integrada de RED do MEC</strong>, entendida como obra intelectual em seu conjunto, é de titularidade do Ministério da Educação. Sua disponibilização ocorrerá de acordo com os termos da <a style={{color:"#00BCD4"}} href="https://creativecommons.org/licenses/by-sa/4.0/deed.pt_BR" target="_blank">Licença Pública Creative Commons do tipo CC BY-SA</a>, exceto nos casos em que for indicado de outra forma.</p>
                <p>A licença CC BY SA é uma licença aberta e permite que seja feita cópia, redistribuição, adaptação e criação de obras derivadas, inclusive uso comercial, desde que o autor seja referenciado e que a licença da obra derivada seja também CC BY SA, garantindo o constante caráter aberto das produções.</p>
                <p>Aplica-se aos códigos de software desenvolvidos pela <strong>Plataforma Integrada de RED do MEC</strong> a <a style={{color:"#00BCD4"}} href="https://www.gnu.org/licenses/gpl.html" target="_blank">Licença Pública Geral Affero GNU GPL</a> (veja a tradução livre <a style={{color:"#00BCD4"}} href="https://creativecommons.org/licenses/GPL/2.0/legalcode.pt" target="_blank">aqui</a>), que visa garantir a liberdade de compartilhar e de modificar softwares livres.</p>
                <p>O usuário que utilizar a <strong>Plataforma Integrada de RED do MEC</strong> como repositório, ou seja, para armazenamento de conteúdo, garante que detém todos os direitos e autorizações para a publicação do conteúdo e deverá escolher uma das licenças Creative Commons elencadas no formulário no momento de cadastro do material. As licenças Creative Commons relacionadas abaixo serão aceitas na <strong>Plataforma Integrada de RED do MEC</strong>, pois garantem o devido crédito pela criação original do usuário e permitem as seguintes ações de uso:</p>
                <ul>
                  <li>
                    <p><strong>CC-BY</strong>: esta licença permite que outros distribuam, remixem, adaptem e criem a partir do seu trabalho, mesmo para fins comerciais, desde que lhe atribuam o devido crédito pela criação original.</p>
                  </li>
                  <li>
                    <p><strong>CC-BY-SA</strong>: esta licença permite que outros remixem, adaptem e criem a partir do seu trabalho, mesmo para fins comerciais, desde que lhe atribuam o devido crédito e que licenciem as novas criações sob termos idênticos.</p>
                  </li>
                  <li>
                    <p><strong>CC-BY-NC</strong>: esta licença permite que outros remixem, adaptem e criem a partir do seu trabalho para fins não comerciais e, embora os novos trabalhos tenham de lhe atribuir o devido crédito e não possam ser usados para fins comerciais, os usuários não têm de licenciar esses trabalhos derivados sob os mesmos termos.</p>
                  </li>
                  <li>
                    <p><strong>CC-BY-NC-SA</strong>: esta licença permite que outros remixem, adaptem e criem a partir do seu trabalho para fins não comerciais, desde que atribuam o devido crédito e que licenciem as novas criações sob termos idênticos.</p>
                  </li>
                </ul>
                <p>Cabe ao Usuário verificar a compatibilidade da licença do material obtido na <strong>Plataforma Integrada de RED do MEC</strong> para utilizar em outras produções. Para consultar a compatibilidade das licenças Creative Commons, há uma ferramenta disponível no site <a style={{color:"#00BCD4"}} href="http://aberta.org.br/compatibilidade/" target="_blank">Iniciativa Educação Aberta</a>.</p>
                <p>O usuário da <strong>Plataforma Integrada de RED do MEC</strong> responde por todo o conteúdo publicado por meio de seu perfil, inclusive no que diz respeito à violação dos direitos autorais relacionados a tais postagens. Ao inserir um conteúdo de sua autoria para armazenamento, o usuário concorda e autoriza o licenciamento ao escolher uma das licenças abertas descritas no formulário de publicação, de forma a permitir não só o seu reconhecimento pleno de autoria, como também a possibilidade de replicação, reedição e reformulação de suas postagens por terceiros, com o objetivo de possibilitar o compartilhamento e a reutilização de conteúdo educacional.</p>
                <p>A <strong>Plataforma Integrada de RED do MEC</strong> poderá disponibilizar endereços eletrônicos de outros sítios externos, por meio de links, o que não significa que estes sejam de sua propriedade ou por ele operados. A presença de links para outros sites não implica relação de sociedade ou de supervisão da <strong>Plataforma Integrada de RED do MEC</strong> com esses sites e seus conteúdos. Os campos descritivos de cada recurso conterão informações específicas sobre as licenças dos mesmos. Cabe ao usuário verificar a licença de cada recurso.</p>
                <p>É vedado o uso não autorizado da obra ou seu uso em desconformidade com a legislação autoral e com os termos da licença mencionada.</p>
              </div>
            </Grid>
            <Grid item xs={12} md={1}></Grid>
            <Grid item xs={12} md={4}>
              <div style={{color:"#00BCD4"}}>
                <p>BASICAMENTE.</p>
                <p>A Plataforma MEC RED, por ser entendida como obra intelectual, possui uma licença aberta de uso que permite a reutilização e o compartilhamento do conteúdo, inclusive para uso comercial, desde que o autor seja referenciado. Além disso, no caso de obras derivadas, a licença deverá ser a mesma da obra original.</p>
                <p>Os códigos de software desenvolvidos para a Plataforma, possuem uma licença pública, de software livre, que garante a liberdade de compartilhamento e modificação dos mesmos.</p>
                <p>Os conteúdos publicados e armazenados na Plataforma pelos usuários, serão sempre abertos, sendo permitidas ações de edição e compartilhamento desde que o autor seja referenciado. Cabe ao usuário decidir se o recurso poderá ser utilizado somente para fins não comerciais e se os trabalhos derivados deverão ter os termos idênticos ao original, selecionando uma das opções de licença disponíveis no momento de upload do recurso.</p>
              </div>
            </Grid>
          </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel5'} onChange={handleChange('panel5')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel5d-content" id="panel5d-header">
          <TypographyColorido>5. Práticas de uso e armazenamento</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
          <Grid container spacing={3}>
            <Grid item xs={12} md={7}>
              <div>
                <p>A depender da capacidade de espaço no servidor, a <strong>Plataforma Integrada de RED do MEC</strong> poderá retirar conteúdos armazenados na plataforma, observados os critérios de antiguidade e do tamanho dos arquivos disponibilizados, mediante notificação e justificativa ao usuário.</p>
              </div>
            </Grid>
            <Grid item xs={12} md={1}></Grid>
            <Grid item xs={12} md={4}>
              <div>
                <p>BASICAMENTE,</p>
                <p>O usuário será notificado caso algum conteúdo tenha que ser retirado da Plataforma por falta de espaço no servidor.</p>
              </div>
            </Grid>
          </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel6'} onChange={handleChange('panel6')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel6d-content" id="panel6d-header">
          <TypographyColorido>6. Privacidade da informação</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
          <Grid container spacing={3}>
            <Grid item xs={12} md={7}>
              <div >
                <p>A <strong>Plataforma Integrada de RED do MEC</strong> tomará todas as medidas possíveis para manter a confidencialidade e a segurança de suas informações. No entanto, a <strong>Plataforma Integrada de RED do MEC</strong> não responderá por prejuízos que possam ser derivados da violação dessas medidas por parte de terceiros que subvertam os sistemas de segurança para acessar as informações de Usuários.</p>
                <p>A <strong>Plataforma Integrada de RED do MEC</strong> solicitará alguns dados pessoais para seu cadastro. Além disso, dados sobre a interação dos usuários e seu comportamento na plataforma são coletados de maneira automática. Esses dados nunca serão vendidos, alugados, trocados ou fornecidos para fins comerciais. No entanto, o MEC poderá colaborar com instituições públicas parceiras, como universidades, para análise desses dados bem como de qualquer conteúdo da plataforma para para fins de pesquisa, divulgação e melhoria dos serviços. Dados pessoais que possam identificá-lo nunca serão compartilhados.</p>
                <p>Dados que não identificam o usuário serão armazenados indefinidamente para fins de pesquisa.</p>
              </div>
            </Grid>
            <Grid item xs={12} md={1}></Grid>
            <Grid item xs={12} md={4}>
              <div style={{color:"#00BCD4"}}>
                <p>BASICAMENTE,</p>
                <p>Para manter a confidencialidade e a segurança dos dados, a Plataforma MEC RED tomará todas as medidas possíveis.</p>
                <p>Os dados sobre interação e comportamento dos usuários nunca serão comercializados, mas poderão ser analisados para fins de pesquisa, divulgação e melhorias, sem a identificação dos usuários.</p>
              </div>
            </Grid>
          </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel7'} onChange={handleChange('panel7')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel7d-content" id="panel7d-header">
          <TypographyColorido>7. Violação no sistema ou na base de dados</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
        <Grid container spacing={3}>
          <Grid item xs={12} md={7}>
            <div  >
              <p>O responsável por qualquer intromissão, ou tentativa de intromissão, na <strong>Plataforma Integrada de RED do MEC</strong> ou por atividade que viole ou contrarie as disposições legais aplicáveis ou as cláusulas destes Termos de Uso estará sujeito à aplicação das sanções previstas neste instrumento, das ações legais pertinentes e indenizações por eventuais danos causados.</p>
            </div>
          </Grid>
          <Grid item xs={12} md={1}></Grid>
          <Grid item xs={12} md={4}>
            <div style={{color:"#00BCD4"}}>
              <p>BASICAMENTE,</p>
              <p>Serão aplicadas as sanções previstas ou as ações legais ao responsável por intromissão, ou tentativa de intromissão, na Plataforma MEC RED.</p>
            </div>
          </Grid>
        </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel8'} onChange={handleChange('panel8')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel8d-content" id="panel8d-header">
          <TypographyColorido>8. Sanções</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
        <Grid container spacing={3}>
          <Grid item xs={12} md={7}>
            <div  >
              <p>Sem prejuízo de outras medidas, a <strong>Plataforma Integrada de RED do MEC</strong> poderá advertir, bloquear, desativar ou remover, temporária ou definitivamente, a conta e conteúdos disponibilizados por um usuário, em qualquer momento, e iniciar as ações legais cabíveis caso:</p>
              <ul>
                <li>
                  <p>o usuário não cumprir qualquer dispositivo destes Termos de Uso;</p>
                </li>
                <li>
                  <p>o usuário praticar atos fraudulentos ou dolosos;</p>
                </li>
                <li>
                  <p>o MEC entender que as postagens, o conteúdo disponibilizado ou qualquer atitude do usuário tenham causado algum dano a terceiros ou à própria Plataforma, ou tenham a potencialidade de assim o fazer.</p>
                </li>
              </ul>
            </div>
          </Grid>
          <Grid item xs={12} md={1}></Grid>
          <Grid item xs={12} md={4}>
            <div style={{color:"#00BCD4"}}>
              <p>BASICAMENTE,</p>
              <p>No caso do usuário não cumprir qualquer item destes Termos, praticar atos fraudulentos ou dolosos ou causar dano a alguém ou à Plataforma MEC RED, sua conta poderá ser bloqueada, desativada ou removida, em caráter temporário ou definitivo.</p>
            </div>
          </Grid>
        </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel9'} onChange={handleChange('panel9')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel9d-content" id="panel9d-header">
          <TypographyColorido>9. Limitações de responsabilidade</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
        <Grid container spacing={3}>
          <Grid item xs={12} md={7}>
            <div  >
              <p>Em nenhuma situação a <strong>Plataforma Integrada de RED do MEC</strong> e o Ministério da Educação serão responsáveis por quaisquer danos, prejuízos ou outro efeito, direto ou indireto, relacionados ao uso, por parte de seus usuários, leitores ou de qualquer outra pessoa, deste sítio, de seu conteúdo ou de qualquer outro website mencionado.</p>
              <p>O usuário reconhece que será integralmente responsável pelos materiais enviados à <strong>Plataforma Integrada de RED do MEC</strong> e se compromete a responder por quaisquer reivindicações, demandas, penalidades e todos os danos, perdas e despesas, causados à <strong>Plataforma Integrada de RED do MEC</strong>.</p>
              <p>Todo autor de conteúdo exibido na <strong>Plataforma Integrada de RED do MEC</strong> retém os seus direitos e responsabilidades autorais, nos termos da Lei n. 9.610/1998, sem prejuízo dos termos de licenciamento de livre uso, conforme exposto nestes Termos de Uso, no item “Licença de uso do conteúdo”.</p>
              <p>Se o usuário verificar que qualquer comentário ou participação na <strong>Plataforma Integrada de RED do MEC</strong> infringem um direito de sua titularidade ou de um terceiro, deverá entrar em contato imediatamente na forma indicada neste mesmo documento, no item “Como reportar violações”.</p>
            </div>
          </Grid>
          <Grid item xs={12} md={1}></Grid>
          <Grid item xs={12} md={4}>
            <div style={{color:"#00BCD4"}}>
              <p>BASICAMENTE,</p>
              <p>A Plataforma MEC RED e o Ministério da Educação não serão responsáveis por danos, prejuízos ou outro efeito relacionados ao uso da Plataforma por parte de qualquer pessoa.</p>
              <p>O usuário é integralmente responsável pelos materiais enviados e por qualquer conteúdo publicado, se comprometendo a responder por eles, quando necessário.</p>
            </div>
          </Grid>
        </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel10'} onChange={handleChange('panel10')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel10d-content" id="panel10d-header">
          <TypographyColorido>10.Inexistência de vínculo</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
        <Grid container spacing={3}>
          <Grid item xs={12} md={7}>
            <div  >
              <p>A adesão a estes Termos de Uso pelo usuário não gera nenhum contrato, mandato, franquia ou vínculo de tipo trabalhista, societário, de parceria ou associativo entre a <strong>Plataforma Integrada de RED do MEC</strong> e o usuário.</p>
            </div>
          </Grid>
          <Grid item xs={12} md={1}></Grid>
          <Grid item xs={12} md={4}>
            <div style={{color:"#00BCD4"}}>
              <p>BASICAMENTE,</p>
              <p>Não há nenhum tipo de vínculo (trabalhista, parceria, etc) entre a Plataforma e o usuário.</p>
            </div>
          </Grid>
        </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel11'} onChange={handleChange('panel11')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel11d-content" id="panel11d-header">
          <TypographyColorido>11. Como reportar violações</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
        <Grid container spacing={3}>
          <Grid item xs={12} md={7}>
            <div  >
              <p>Nem todo o conteúdo disponibilizado pelo usuário nas áreas de comentário e debates é lido pela administração da <strong>Plataforma Integrada de RED do MEC</strong>.</p>
              <p>Se algum artigo, notícia, comentário ou outro conteúdo da <strong>Plataforma Integrada de RED do MEC</strong> violar qualquer direito do usuário, de terceiros ou a legislação aplicável, o usuário poderá usar a funcionalidade "Reportar" nas páginas que houver essa opção ou, quando não houver, entrar em contato com a administração da <strong>Plataforma Integrada de RED do MEC</strong> pelo formulário de “Contato”, mencionando de forma específica e detalhada a violação.</p>
              <p>De posse das informações, a <strong>Plataforma Integrada de RED do MEC</strong> poderá analisar e resolver a questão tão breve quanto possível. Caso a informação esteja incompleta, ou com detalhamento insuficiente, a <strong>Plataforma Integrada de RED do MEC</strong> poderá entrar em contato para solicitar a complementação, possivelmente atrasando a providência desejada.</p>
            </div>
          </Grid>
          <Grid item xs={12} md={1}></Grid>
          <Grid item xs={12} md={4}>
            <div style={{color:"#00BCD4"}}>
              <p>BASICAMENTE,</p>
              <p>O usuário poderá reportar, utilizando a funcionalidade “Reportar” ou pelo formulário de “Contato”, qualquer tipo de conteúdo publicado na Plataforma MEC RED que viole os direitos dos usuários, de terceiros ou a legislação aplicável.</p>
            </div>
          </Grid>
        </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel12'} onChange={handleChange('panel12')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel12d-content" id="panel12d-header">
          <TypographyColorido>12. Modificações nos Termos de Uso</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
        <Grid container spacing={3}>
          <Grid item xs={12} md={7}>
            <div  >
              <p>A <strong>Plataforma Integrada de RED do MEC</strong> poderá alterar, a qualquer tempo, estes Termos de Uso, mediante declaração pública no site, visando seu aprimoramento e melhoria dos serviços prestados. Os novos Termos de Uso entrarão em vigor a partir de sua publicação na plataforma. Usuários cadastrados receberão notificação dessa alteração no e-mail de cadastro e haverá divulgação/chamada na página principal do Sistema. No prazo de 72 (setenta e duas) horas, contadas a partir da publicação das modificações, o usuário poderá comunicar-se com a <strong>Plataforma Integrada de RED do MEC</strong>, caso não concorde com os novos Termos de Uso. Nesse caso, a conta do usuário será desativada. Não havendo manifestações no prazo estipulado, entender-se-á que o Usuário aceitou tacitamente os novos Termos de Uso.</p>
            </div>
          </Grid>
          <Grid item xs={12} md={1}></Grid>
          <Grid item xs={12} md={4}>
            <div style={{color:"#00BCD4"}}>
              <p>BASICAMENTE,</p>
              <p>Com o objetivo de melhorar os serviços prestados, estes Termos podem ser alterados, a qualquer tempo. Caso ocorra, os usuários serão notificados e terão um período para se manifestar em relação às alterações.</p>
            </div>
          </Grid>
        </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
      <MuiExpansionPanelMargem square expanded={expanded === 'panel13'} onChange={handleChange('panel13')}>
        <MuiExpansionPanelSummaryColorido expandIcon={<AddIcon />} aria-controls="panel13d-content" id="panel13d-header">
          <TypographyColorido>13. Foro</TypographyColorido>
        </MuiExpansionPanelSummaryColorido>
        <MuiExpansionPanelDetailsColorido>
        <Grid container spacing={3}>
          <Grid item xs={12} md={7}>
            <div >
              <p>Para dirimir dúvidas ou litígios referentes à interpretação e ao cumprimento destes Termos de Uso, as partes se submeterão ao Foro da Justiça Federal, Seção Judiciária do Distrito Federal.</p>
            </div>
          </Grid>
          <Grid item xs={12} md={1}></Grid>
          <Grid item xs={12} md={4}>
            <div style={{color:"#00BCD4"}}>
              <p>BASICAMENTE,</p>
              <p>Em caso de dúvidas ou litígios, é preciso recorrer ao Foro da Justiça Federal.</p>
            </div>
          </Grid>
        </Grid>
        </MuiExpansionPanelDetailsColorido>
      </MuiExpansionPanelMargem>
    </div>
  );
}
